aboutsummaryrefslogtreecommitdiff
path: root/tests/mock_guest.c
diff options
context:
space:
mode:
authorMike Gabriel <mike.gabriel@das-netzwerkteam.de>2012-11-09 01:17:16 +0100
committerMike Gabriel <mike.gabriel@das-netzwerkteam.de>2012-11-09 01:17:16 +0100
commit42b8b279e62e6e2f5a7455e30bb0a211763ee187 (patch)
tree9d0e09c594f340a7ed9db8cc910a717890ef5f28 /tests/mock_guest.c
parente92b549c49833e3150d60e8773a6731fc49d1249 (diff)
downloadlibpam-x2go-42b8b279e62e6e2f5a7455e30bb0a211763ee187.tar.gz
libpam-x2go-42b8b279e62e6e2f5a7455e30bb0a211763ee187.tar.bz2
libpam-x2go-42b8b279e62e6e2f5a7455e30bb0a211763ee187.zip
fork libpam-x2go from libpam-freerdp
Diffstat (limited to 'tests/mock_guest.c')
-rw-r--r--tests/mock_guest.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/mock_guest.c b/tests/mock_guest.c
index 8bf2c3a..3327da0 100644
--- a/tests/mock_guest.c
+++ b/tests/mock_guest.c
@@ -68,7 +68,7 @@ void _exit (int exitcode)
#define BUFFER_SIZE 512
/*Borrowed this code form socket-sucker.c in lightdm-remote-session-freerdp*/
int
socket_sucker ()
{
@@ -85,7 +85,7 @@ socket_sucker ()
serv_addr.sun_family = AF_UNIX;
- int printsize = snprintf(serv_addr.sun_path, sizeof(serv_addr.sun_path) - 1, "%s/%s", home, ".freerdp-socket");
+ int printsize = snprintf(serv_addr.sun_path, sizeof(serv_addr.sun_path) - 1, "%s/%s", home, ".x2go-socket");
if (printsize > sizeof(serv_addr.sun_path) - 1 || printsize < 0) {
return -1;
}
@@ -68,7 +68,7 @@ void _exit (int exitcode)
#define BUFFER_SIZE 512
-/*Borrowed this code form socket-sucker.c in lightdm-remote-session-freerdp*/
+/*Borrowed this code form socket-sucker.c in lightdm-remote-session-x2go*/
int
socket_sucker ()